Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(256)

Unified Diff: base/android/library_loader/library_loader_hooks.h

Issue 2015533005: Record the return value of NativeLibraryPreloader.loadLibrary in UMA (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: base/android/library_loader/library_loader_hooks.h
diff --git a/base/android/library_loader/library_loader_hooks.h b/base/android/library_loader/library_loader_hooks.h
index 1ed09bd54f00020c62e142480642281580f42a06..3e8969bc59a2c93671bf3e2a4e9d03fefffab096 100644
--- a/base/android/library_loader/library_loader_hooks.h
+++ b/base/android/library_loader/library_loader_hooks.h
@@ -27,9 +27,10 @@ enum LibraryProcessType {
PROCESS_WEBVIEW_CHILD = 4,
};
-// Record any pending renderer histogram value as a histogram. Pending values
-// are set by RegisterChromiumAndroidLinkerRendererHistogram.
-BASE_EXPORT void RecordChromiumAndroidLinkerRendererHistogram();
+// Record any pending renderer histogram value as histograms. Pending values
+// are set by RegisterChromiumAndroidLinkerRendererHistogram and
+// RegisterLibraryPreloaderRendererHistogram.
+BASE_EXPORT void RecordLibraryLoaderRendererHistograms();
// Registers the callbacks that allows the entry point of the library to be
// exposed to the calling java code. This handles only registering the

Powered by Google App Engine
This is Rietveld 408576698